A package for maximum likelihood density fitting and simulation.

This package is still in the planning phase. At the moment, two stages are planned.

In the first stage, users will be able to fit common distributions to their data by the maximum likelihood estimation technique. Users will also be able to simulate sampling from these fitted distributions.

In the second stage, users will be able to input custom distributional forms by pasting LaTeX code. At first, only continuous distributions will be allowed. Piecewise functions will be incorporated later.